@@ -11,7 +11,7 @@ use Rose::DB::Object::Constants qw(STATE_LOADING STATE_IN_DB);
 # XXX: A value that is unlikely to exist in a primary key column value
 use constant PK_JOIN => "\0\2,\3\0";
 
-our $VERSION = '0.10';
+our $VERSION = '0.51';
 
 our $Debug = 0;
 
@@ -25,7 +25,9 @@ use Rose::Class::MakeMethods::Generic
   [
     'error',
     'total', 
-    'error_mode', 
+    'error_mode',
+    '_object_class',
+    '_base_name',
     'default_objects_per_page',
   ],
 );
@@ -146,8 +148,13 @@ sub make_manager_methods
   Carp::croak "Invalid 'methods' parameter - should be a hash ref"
     unless(ref $args{'methods'} eq 'HASH');
 
+  $class->_base_name($args{'base_name'});
+  $class->_object_class($object_class);
+
   while(my($name, $types) = each %{$args{'methods'}})
   {
+    $class->_base_name($name)  unless($args{'base_name'});
+
     my $have_full_name = ($name =~ s/\(\)$//) ? 1 : 0;
 
     Carp::croak "Invalid value for the '$name' parameter"
@@ -1810,6 +1817,33 @@ sub update_objects
   return $count;
 }
 
+sub perl_class_definition
+{
+  my($class) = shift;
+
+  my $object_class = $class->object_class || $class->_object_class;
+
+  no strict 'refs';
+  my @isa = @{"${class}::ISA"};
+
+  my $use_bases = join("\n", map { "use $_;" } @isa);
+
+  return<<"EOF";
+package $class;
+
+use $object_class;
+
+$use_bases
+our \@ISA = qw(@isa);
+
+sub object_class { '@{[ $class->object_class || $class->_object_class ]}' }
+
+__PACKAGE__->make_manager_methods('@{[ $class->_base_name ]}');
+
+1;
+EOF
+}
+
 1;
 
 __END__
@@ -2633,6 +2667,25 @@ Here we've coerced the caller-friendly C<with_categories> boolean flag parameter
 
 This is the typical evolution of an object manager method.  It starts out as being auto-generated by L<make_manager_methods|/make_manager_methods>, then becomes customized as new arguments are added.
 
+=item B<perl_class_definition>
+
+Attempts to create the Perl source code that is equivalent to the current class.  This works best for classes created via L<Rose::DB::Object::Metadata>'s L<make_manager_class|Rose::DB::Object::Metadata/make_manager_class> method, but it will also work most of the time for classes whose methods were created using L<make_manager_methods|/make_manager_methods>.
+
+The Perl code is returned as a string.  Here's an example:
+
+  package My::Product::Manager;
+  
+  use My::Product;
+  
+  use Rose::DB::Object::Manager;
+  our @ISA = qw(Rose::DB::Object::Manager);
+  
+  sub object_class { 'My::Product' }
+  
+  __PACKAGE__->make_manager_methods('products');
+  
+  1;
+
 =item B<update_objects [PARAMS]>
 
 Update rows in a table fronted by a L<Rose::DB::Object>-derived class based on PARAMS, where PARAMS are name/value pairs.  Returns the number of rows updated, or undef if there was an error.
